import fs from "fs-extra";
import pico from "picocolors";
import updateNotifier from "update-notifier";
import gstring from "gradient-string";
import consola from "consola";
import inquirer from "inquirer";
import envinfo from "envinfo";
import CliTable from "tty-table";
import { Command } from "commander";
import { request } from "undici";
import { glob } from "glob";
import { execa } from "execa";
import semver from "semver";
import minimist from "minimist";
import prompts from "prompts";
import getGitRepoInfo from "git-repo-info";
import fuzzypath from "inquirer-fuzzy-path";
import inquirerPrompt from "inquirer-autocomplete-prompt";
import open from "open";
import dotenv from "dotenv";
import { cosmiconfig } from "cosmiconfig";
import dotenvExpand from "dotenv-expand";
import { filesize } from "filesize";
import recursiveReaddir from "recursive-readdir";
import Configstore from "configstore";
import mime from "mime";
inquirer.registerPrompt("fuzzypath", fuzzypath);
inquirer.registerPrompt("autocomplete", inquirerPrompt);
import * as filetype from "file-type";
import * as lodash from "lodash-es";
const checkNodeVersion = (wanted, name) => {
  if (!semver.satisfies(process.version, wanted, { includePrerelease: true })) {
    console.log(
      pico.red(
        `You are using Node ${process.version} , but this version of ${name} requires Node ${wanted}.
           Please upgrade your Node version.`
      )
    );
    process.exit(1);
  }
};
const checkUpdate = (pkg) => {
  updateNotifier({
    pkg,
    shouldNotifyInNpmScript: true
  }).notify({
    message: "Update available " + pico.dim("{currentVersion}") + pico.reset(" \u2192 ") + pico.green("{latestVersion}") + " \nRun " + pico.cyan(`pnpm update {packageName}@{latestVersion}`) + " to update",
    defer: false
  });
};
const gs = (str, options = [
  { color: "#42d392", pos: 0 },
  { color: "#42d392", pos: 0.1 },
  { color: "#647eff", pos: 1 }
]) => {
  if (process.stdout.isTTY && process.stdout.getColorDepth() > 8) {
    return gstring(options)(str);
  } else {
    return str;
  }
};
const prepareCli = (packageJson) => {
  if (!packageJson) {
    return {
      name: "",
      version: ""
    };
  }
  const {
    engines: { node },
    name
  } = packageJson;
  checkNodeVersion(node, name);
  checkUpdate(packageJson);
  return packageJson;
};
export {
  CliTable,
  Command,
  Configstore,
  checkNodeVersion,
  checkUpdate,
  consola,
  cosmiconfig,
  dotenv,
  dotenvExpand,
  envinfo,
  execa,
  filesize,
  filetype,
  fs,
  getGitRepoInfo,
  glob,
  gs,
  inquirer,
  lodash,
  mime,
  minimist,
  open,
  pico,
  prepareCli,
  prompts,
  recursiveReaddir,
  request,
  semver
};
